package info.devzero.jerry.plugins.bukkit.netherblocks;

import java.io.File;
import java.util.Arrays;
import java.util.List;
import java.util.logging.Logger;

import org.bukkit.event.Event.Priority;
import org.bukkit.event.Event;
import org.bukkit.plugin.java.JavaPlugin;
import org.bukkit.plugin.PluginManager;
import org.bukkit.util.config.Configuration;

/*
 * NetherBlocks - a Bukkit plugin that allows users to get Nether blocks using gold tools
 * Copyright (C) 2011 Jerry <j3rry1337@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 * NetherBlocks - make certain blocks drop items from the Nether
 *
 * @author Jerry <j3rry1337@gmail.com>
 */
public class NetherBlocks extends JavaPlugin {
	private final NetherBlocksBlockListener blockListener = new NetherBlocksBlockListener(this);
	private final Logger log = Logger.getLogger("Minecraft");
	
	// Configuration
	public Integer glowstoneMin;
	public Integer glowstoneMax;
	public List<Integer> soulsandBlocks;
	public List<Integer> glowstoneBlocks;
	public List<Integer> netherrackBlocks;
	public List<Integer> soulsandTools;
	public List<Integer> glowstoneTools;
	public List<Integer> netherrackTools;

	public void onDisable() {
		log.info("[" + getDescription().getName() + "] " + getDescription().getName() + " version " + getDescription().getVersion() + " disabled.");
	}
	
	private void loadConfiguration() {
		Configuration config = getConfiguration();
		
		glowstoneMin = config.getInt("glowstoneMin", 2);
		glowstoneMax = config.getInt("glowstoneMax", 4);
		
		soulsandBlocks = config.getIntList("soulsandBlocks", Arrays.asList(12));
		glowstoneBlocks = config.getIntList("glowstoneBlocks", Arrays.asList(2, 3));
		netherrackBlocks = config.getIntList("netherrackBlocks", Arrays.asList(1));
		
		soulsandTools = config.getIntList("soulsandTools", Arrays.asList(284));
		glowstoneTools = config.getIntList("glowstoneTools", Arrays.asList(284));
		netherrackTools = config.getIntList("netherrackTools", Arrays.asList(285));
	}
	
	public void onEnable() {
		// Check for configuration file
		File configfile = new File(getDataFolder(), "config.yml");
		Configuration config = getConfiguration();
		if (!configfile.exists()) {
			log.info("[" + getDescription().getName() + "] Configuration file not found. Creating default configuration file.");
			
			config.setProperty("glowstoneMin", 2);
			config.setProperty("glowstoneMax", 4);
			
			config.setProperty("soulsandBlocks", Arrays.asList(12));
			config.setProperty("glowstoneBlocks", Arrays.asList(2, 3));
			config.setProperty("netherrackBlocks", Arrays.asList(1));
			
			config.setProperty("soulsandTools", Arrays.asList(284));
			config.setProperty("glowstoneTools", Arrays.asList(284));
			config.setProperty("netherrackTools", Arrays.asList(285));
			config.save();
			
			loadConfiguration();
		}
		else {
			loadConfiguration();
			
			log.info("[" + getDescription().getName() + "] Configuration file has been loaded.");
		}
		
		// Register events
		PluginManager pm = getServer().getPluginManager();
		pm.registerEvent(Event.Type.BLOCK_BREAK, blockListener, Priority.Normal, this);

		// Yes, we've been loaded!
		log.info("[" + getDescription().getName() + "] " + getDescription().getName() + " version " + getDescription().getVersion() + " enabled.");
	}
}
