package info.devzero.jerry.plugins.bukkit.netherblocks;

import org.bukkit.Location;
import org.bukkit.Material;
import org.bukkit.block.Block;
import org.bukkit.event.block.BlockListener;
import org.bukkit.event.block.BlockBreakEvent;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;

/*
 * NetherBlocks - a Bukkit plugin that allows users to get Nether blocks using gold tools
 * Copyright (C) 2011 Jerry <j3rry1337@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

/**
 * NetherBlocks block listener
 * @author Jerry <j3rry1337@gmail.com>
 */
public class NetherBlocksBlockListener extends BlockListener {
	private final NetherBlocks plugin;

	public NetherBlocksBlockListener(final NetherBlocks plugin) {
		this.plugin = plugin;
	}

	public void onBlockBreak(BlockBreakEvent event) {
		Block block = event.getBlock();
		Player player = event.getPlayer();
		Location location = block.getLocation();
		
		if (event.isCancelled()) {
			return;
		}

		// [insert configured tool here] broke [insert configured block here], make it drop Soul Sand
		if (plugin.soulsandTools.contains(player.getItemInHand().getTypeId())) {
			if (plugin.soulsandBlocks.contains(block.getTypeId())) {
				// stop normal drop and destroy block by turning it into air
				block.setType(Material.AIR);
				block.getWorld().dropItemNaturally(location, new ItemStack(Material.SOUL_SAND, 1));
			}
		}
		
		// [insert configured tool here] broke [insert configured block here], make it drop Glowstone Dust
		if (plugin.glowstoneTools.contains(player.getItemInHand().getTypeId())) {
			if (plugin.glowstoneBlocks.contains(block.getTypeId())) {
				// stop normal drop and destroy block by turning it into air
				block.setType(Material.AIR);
			
				// drop random amount of Glowstone Dust
				int min = plugin.getConfiguration().getInt("glowstoneMin", 2);
				int max = plugin.getConfiguration().getInt("glowstoneMax", 4);
				int num = min + (int) (Math.random() * ((max - min) + 1));
				for (int i = 0; i < num; i++)
				{
					block.getWorld().dropItemNaturally(location, new ItemStack(Material.GLOWSTONE_DUST, 1));
				}
			}
		}
		
		// [insert configured tool here] broke [insert configured block here], make it drop Netherrack
		if (plugin.netherrackTools.contains(player.getItemInHand().getTypeId())) {
			if (plugin.netherrackBlocks.contains(block.getTypeId())) {
				// stop normal drop and destroy block by turning it into air
				block.setType(Material.AIR);
				block.getWorld().dropItemNaturally(location, new ItemStack(Material.NETHERRACK, 1));
			}
		}
	}
}
